import React, { createElement, PropTypes } from 'react';
import classnames from 'classnames';

import namespace from '../../namespace';

const classNamespace = namespace('app__components-button', true);
const noop = function () {};

export default class Button extends React.Component {
  static propTypes = {
    onClick: PropTypes.func
  };

  static defaultProps = {
    onClick: noop
  };

  onButtonClick = (e) => {
    const { disable, loading, onClick } = this.props;

    if (disable || loading) {
      return this;
    }

    onClick(e);
  }

  render () {
    const { text, primary, disable, loading, warning } = this.props;

    const classes = classnames({
      [classNamespace()]: true,
      [classNamespace(null, 'default')]: (!primary && !warning),
      [classNamespace(null, 'warning')]: !!warning,
      [classNamespace(null, 'primary')]: !!primary,
      [classNamespace(null, 'loading')]: !!loading,
      [classNamespace(null, 'disable')]: !!disable,
    });

    let loadingElement;

    if (loading) {
      loadingElement = (
        <i className="app__components-loading-icon"></i>
      );
    }

    return (
      <button className={classes} onClick={this.onButtonClick}>
        {loadingElement}
        <span className={classNamespace('text')}>{text || this.props.children}</span>
      </button>
    );
  }
}