import React, { createElement, PropTypes } from 'react';
import classnames from 'classnames';
import { assign } from 'lodash';

import namespace from '../../namespace';

import Exception from './exception';

const classNamespace = namespace('app__components-editor', true);
const noop = function () {};

export default class CodeEditor extends React.Component {
  static propTypes = {
    onChange: PropTypes.func
  };

  static defaultProps = {
    onChange: noop
  };

  onCodeChange = (value, e) => {
    const { onChange } = this.props;

    onChange(value, e);
  }

  componentDidMount () {
    const editor = window.monaco.editor;
    const codeView = this.refs.codeView;
    const { value } = this.props;

    const props = {
      value,
      language: 'html',
      theme: 'vs-dark',
      folding: true
    }

    if (codeView) {
      this.editor = editor.create(codeView, assign({}, props));
      this.editor.onDidChangeModelContent((object) => {
        this.onCodeChange(this.editor.model.getValue(), object);
      });
    }
  }

  componentWillReceiveProps (nextProps) {
    if ('value' in nextProps) {
      if (this.editor) {
        if (!(nextProps.value === this.props.value)) {
          // this.editor.setValue(nextProps.value);
        }
      }
    }
  }

  render () {

    return (
      <div className={classNamespace('code')} ref="codeView">
      </div>
    );
  }
}