import React, { createElement, PropTypes } from 'react';
import classnames from 'classnames';
import namespace from '../../namespace';

import Exception from './exception';

const classNamespace = namespace('app__components-editor', true);
const noop = function () {};

export default class File extends React.Component {
  static propTypes = {
    onSelect: PropTypes.func
  };

  static defaultProps = {
    onSelect: noop
  };

  constructor () {
    super();

    this.state = {
      fileName: null
    };
  }

  onSelectChange = (e) => {
    this.setState();
  }

  keyRender () {
    const { text } = this.props;

    if (text) {
      return (
        <div className={classNamespace('key')}>
          {text}
        </div>
      );
    }
  }

  fileRender () {
    const { value, defaultProps, disable  } = this.props;

    const props = {
      value,
      disabled: disable,
      onChange: this.onSelectChange
    };

    const classes = classnames({
      [classNamespace('value')]: true,
      [classNamespace('file-value')]: true,
      [classNamespace('file-exist')]: this.state.fileName,
    });

    return (
      <div className={classes}>
        <input
          className={classNamespace('file-input')}
          {...props}
          type="file"
        />
        
      </div>
      
    );
  }

  render () {
    const { vertical, exception } = this.props;

    const classes = classnames({
      [classNamespace('cell', 'vertical')]: !!vertical,
      [classNamespace('cell', 'exception')]: !!exception,
      [classNamespace('file')]: true,
      [classNamespace('cell')]: true
    });

    return (
      <div className={classes}>
        {this.keyRender()}
        {this.fileRender()}
        <Exception message={exception} visiable={!!exception} onClose={this.onExceptionClose} />
      </div>
    );
  }
}