import React, { createElement, PropTypes } from 'react';
import classnames from 'classnames';

import namespace from '../../namespace';
import Exception from './exception';

const classNamespace = namespace('app__components-editor', true);
const noop = function () {};

export default class Input extends React.Component {
  static propTypes = {
    onChange: PropTypes.func,
    onExceptionClose: PropTypes.func    
  };

  static defaultProps = {
    onChange: noop,
    onExceptionClose: noop  
  };

  constructor (props) {
    super(props);

    this.state = {
      value: props.value
    };
  }

  shouldComponentUpdate (nextProp) {
    if (
      nextProp.value === this.state.value
    ) {
      return false;
    }

    // this.setState({
    //   value: nextProp.value
    // });

    return true;
  }

  componentWillReceiveProps (nextProp) {
    if ('value' in nextProp) {
      this.setState({
        value: nextProp.value
      });
    }
  }

  onExceptionClose = () => {
    const { onExceptionClose } = this.props;

    onExceptionClose();
  }

  onInputChange  = (e) => {
    const { onChange } = this.props;
    const value = e.target.value;

    this.setState({
      value
    });

    onChange(value, e);
  }

  inputRender () {
    const { defaultProps } = this.props;
    const { multiLine, type, cols, rows = 7, placeholder, disable } = defaultProps;  

    if (multiLine) {
      const props = {
        cols,
        rows,
        type,
        placeholder,
        disabled: disable,
        value: this.state.value,
        onChange: this.onInputChange
      };

      const classes = classnames({
        [classNamespace('value')]: true,
        [classNamespace('textarea-value')]: true
      });

      return (
        <textarea className={classes} {...props} onChange={this.onInputChange}></textarea>
      );
    }

    const props = {
      type,
      placeholder,
      disabled: disable,
      value: this.state.value,
      onChange: this.onInputChange
    };

    const classes = classnames({
      [classNamespace('value')]: true,
      [classNamespace('input-value')]: true
    });

    return (
      <input
        className={classes}
        {...props}
      />
    );
  }

  keyRender () {
    const { text } = this.props;

    if (text) {
      return (
        <div className={classNamespace('key')}>
          {text}
        </div>
      );
    }
  }
  

  render () {
    const { vertical, exception } = this.props;

    const classes = classnames({
      [classNamespace('cell', 'vertical')]: !!vertical,
      [classNamespace('cell', 'exception')]: !!exception,
      [classNamespace('input')]: true,
      [classNamespace('cell')]: true
    });

    return (
      <div className={classes}>
        {this.keyRender()}
        {this.inputRender()}
        <Exception message={exception} visiable={!!exception} onClose={this.onExceptionClose} />
      </div>
    );
  }
}