import React, { createElement, PropTypes } from 'react';
import classnames from 'classnames';

import namespace from '../../namespace';
import Exception from './exception';

const classNamespace = namespace('app__components-editor', true);
const noop = function () {};

export default class Select extends React.Component {
  static propTypes = {
    onChange: PropTypes.func,
    onExceptionClose: PropTypes.func
  };

  static defaultProps = {
    onChange: noop,
    onExceptionClose: noop
  };

  constructor (props) {
    super(props);

    this.state = {
      value: props.value
    };
  }

  onSelectChange  = (e) => {
    const { onChange, disable } = this.props;
    const value = e.target.value;

    if (!disable) {
      this.setState({
        value
      });

      onChange(value, e);
    }
  }

  onExceptionClose = () => {
    const { onExceptionClose } = this.props;

    onExceptionClose();
  }

  optionRender () {
    const { options } = this.props;

    return options.map((opt, i) => {
      return (
        <option value={opt.value} key={i}>{opt.text}</option>
      );
    });
  }

  selectRender () {
    const { value, defaultProps, disable  } = this.props;

    const props = {
      value,
      disabled: disable,
      onChange: this.onSelectChange
    };

    const classes = classnames({
      [classNamespace('value')]: true,
      [classNamespace('select-value')]: true,
    });

    return (
      <select
        className={classes}
        {...props}
        {...defaultProps}
      >
        {this.optionRender()}
      </select>
    );
  }

  keyRender () {
    const { text } = this.props;

    if (text) {
      return (
        <div className={classNamespace('key')}>
          {text}
        </div>
      );
    }
  }

  render () {
    const { vertical, exception } = this.props;

    const classes = classnames({
      [classNamespace('cell', 'vertical')]: !!vertical,
      [classNamespace('select')]: true,
      [classNamespace('cell')]: true
    });

    return (
      <div className={classes}>
        {this.keyRender()}
        {this.selectRender()}
        <Exception message={exception} visiable={!!exception} onClose={this.onExceptionClose} />
      </div>
    );
  }
}