import React, { cloneElement, PropTypes, createElement } from 'react';
import classnames from 'classnames';

import namespace from '../../namespace';

const classNamespace = namespace('app__components', true);
const noop = function () {};

export default class Navigation extends React.Component {
  static propTypes = {
    list: PropTypes.array,
    onSelect: PropTypes.func,
    onDelect: PropTypes.func
  };

  static defaultProps = {
    list: [],
    onSelect: noop,
    onDelect: noop
  }

  navigationItemClick (item, e) {
    const { onSelect, onDelect,  } = this.props;

    if (!item.selected) {
      onSelect(item, e);
    }
  }

  navigationRender () {
    const { list } = this.props;

    const elements = list.map((nav, index) => {
      const selected = nav.selected;
      const classes = classnames({
        [classNamespace('navigation-item', 'selected')]: selected,
        [classNamespace('navigation-item')]: true
      });

      return (
        <div className={classes} key={nav.key} onClick={(e) => this.navigationItemClick(nav, e)}>
          <i className={nav.icon}></i>
          <span className={classNamespace('navigation-item-text')}>{nav.text}</span>
        </div>
      );
    });

    return (
      <div className={classNamespace('navigation')}>
        {elements}
      </div>
    );
  }

  render () {
    return (
      this.navigationRender()
    );
  }
}