import React, { createElement, PropTypes } from 'react';
import classnames from 'classnames';

import namespace from '../../namespace';
import 'whatwg-fetch';

const classNamesapce = namespace('app__components', true);
const noop = function () {};

export default class Group extends React.Component {
  static propTypes = {
    editable: PropTypes.bool
  };

  static defaultProps = {
    editable: true
  };

  constructor () {
    super();

    this.state = {
      toggled: false
    };
  }

  onTitleClick = () => {
    const { toggled } = this.state;
    const { editable } = this.props;

    if (editable) {
      this.setState({
        toggled: !toggled
      });
    }
  }

  listRender () {
    const { onItemSelect, list, index } = this.props;

    return list.map((li, i) => {
      const { key, value, disable } = li;
      const spanElement = value.map((name, idx) => {
        return (
          <span className={classNamesapce('rule-name')} key={idx}>
            {name}
          </span>
        );
      });
      const classes = classnames({
        [classNamesapce('rule-item', 'enable')]: !disable,
        [classNamesapce('rule-item')]: true
      });

      return (
        <div className={classes} onClick={() => onItemSelect(li, i)} key={i}>
          <div className={classNamesapce('rule-key')}>{key}</div>
          <div className={classNamesapce('rule-value')}>{spanElement}</div>
        </div>
      );
    });
  }

  render () {
    const { index, text, name, list, onGroupRemove, onGroupEdit, editable } = this.props;
    const classes = classnames({
      [classNamesapce('rule-header', 'toggled')]: this.state.toggled,
      [classNamesapce('rule-header')]: true,
      [classNamesapce('rule-header', 'disable')]: !editable,
    });


    
    return (
      <div className={classNamesapce('rule-single')} key={index}>
        <div className={classes}>
          <div className={classNamesapce('rule-title')} onClick={this.onTitleClick}>
            {text || name}
          </div>

          <div className={classNamesapce('rule-action')}>
            <div className={classnames({
              [classNamesapce('rule-action-edit')]: true,
              [classNamesapce('rule-action-item')]: true
            })} onClick={() => onGroupEdit()}>
              <i className={classnames({
                ['iconfont']: true,
                ['icon-editor-fill']: true
              })}></i>
            </div>

            <div className={classnames({
              [classNamesapce('rule-action-remove')]: true,
              [classNamesapce('rule-action-item')]: true
            })} onClick={() => onGroupRemove()}>
              <i className={classnames({
                ['iconfont']: true,
                ['icon-remove-fill']: true
              })}></i>
            </div>
            
          </div>
        </div>
        <div className={classNamesapce('rule-content')}>
          <div className={classNamesapce('ruledata')}>
            {this.listRender()}
          </div>
        </div>
      </div>
    );
  }
}