import React, { createElement, PropTypes } from 'react';
import classnames from 'classnames';

import namespace from '../../namespace';
import Group from './group';

import 'whatwg-fetch';

const classNamesapce = namespace('app__components', true);
const noop = function () {}

export default class Rules extends React.Component {
  static propTypes = {
    onSelect: PropTypes.func,
    onRemove: PropTypes.func,
    onEdit: PropTypes.func,
    list: PropTypes.array
  };

  static defaultProps = {
    onSelect: noop,
    onRemove: noop,
    onEdit: noop,
    list: []
  };

  onItemSelect = (...args) => {
    const { onSelect } = this.props;

    onSelect(...args);
  }

  onGroupRemove = (rule, index) => {
    const { onRemove } = this.props;

    onRemove(rule, index)
  }

  onGroupEdit = (rule, index) => {
    const { onEdit } = this.props;

    onEdit(rule, index);
  }

  groupRender () {
    const { list } = this.props;

    return list.map((group, index) => {
      const { text, list, name, editable } = group;
      const props = {
        list,
        text,
        name,
        index,
        editable,
        onGroupEdit: () => this.onGroupEdit(group, index, list),
        onGroupRemove: () => this.onGroupRemove(group, index, list),
        onItemSelect: (rule, idx) => this.onItemSelect(rule, idx, group, index, list)
      }

      return (
        <Group {...props} key={index} />
      );
    });
  }

  render () {
    return (
      <div className={classNamesapce('rule')}>
        {this.groupRender()}
      </div>
    );
  }
}